package vocleditor.command;

import org.eclipse.gef.commands.Command;
import org.eclipse.swt.widgets.Shell;

import vocleditor.model.Helpers;
import VOCLModel.IfExp;

/**
 * 
 * Class       : CreateDecisionCommand<br/>
 * Package     : vocleditor.command<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 28.06.2004<br/>
 * Description : Command for Creating a new if-then-else-Expression.<br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 */
public class CreateDecisionCommand extends Command {

	//the index - position for the parent figure
	private int position;
	//the current decision
	private IfExp decision;
	//the parent of the current decision
	private Object parent;
	private Shell shell;
	

	/**
	 * @see org.eclipse.gef.commands.Command#execute()
	 */
	public void execute() {
		if(Helpers.constraintHasAlreadyVOCLExpression(shell,parent) == 1){
					return;
		}
		//set the position of this part in the parent figure
		decision.setIndex(position);
		//insert decision into modell
		Helpers.addToParent(decision,parent,position);
	}
	
	/**
	 * Sets the current index - position for the parent figure.
	 * @param p
	 */
	public void setPosition(int p){
		position = p;
	}
	
	/**
	 * set the current If-then-else-Expression
	 * @param exp
	 */
	public void setDecision(IfExp exp) {
		decision = exp;
	}

	/**
	 * sets the parent of this current if-then-else-Expression
	 * @param object
	 */
	public void setParent(Object object) {
		parent = object;
	}
	
	/**
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	public void undo() {
		Helpers.removeFromParent(parent,position);
	}
	
	/**
	 * @see org.eclipse.gef.commands.Command#redo()
	 */
	public void redo() {
		Helpers.addToParent(decision,parent,position);
	}
	
	public void setShell(Shell shell){
		this.shell = shell;
	}
}
