package vocleditor.command;

import org.eclipse.gef.commands.Command;
import org.eclipse.swt.widgets.Shell;

import vocleditor.dialogs.CreateLetExpressionDialog;
import vocleditor.model.Helpers;
import vocleditor.model.VOCLModelManager;
import VOCLModel.LetExp;
import VOCLModel.VOCLModelFactory;
import VOCLModel.VariableDeclaration;

/**
 * 
 * Class       : CreateLetExpCommand<br/>
 * Package     : vocleditor.command<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 02.07.2004<br/>
 * Description : Command for Creating a new if-then-else-Expression.<br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 */
public class CreateLetExpCommand extends Command {

	//the current Let-In-Exp
	LetExp letexp;
	//the parent
	Object parent;
	Shell shell;
	//the index - position for the parent figure
	int position;
	//the VariableDeclaration for the Let-In-Expression
	VariableDeclaration vardeclar = null;

	/**
	 * Constructor.
	 * @param shell
	 */
	public CreateLetExpCommand(Shell shell) {
		this.shell = shell;
	}
	/**
	 * Set the current Letexpression.
	 * @param exp the current Letexpression
	 */
	public void setLetExp(LetExp exp) {
		letexp = exp;
	}

	/**
	 * Set the parent of the LetExpression.
	 * @param parent
	 */
	public void setParent(Object parent) {
		this.parent = parent;
	}

	/**
	 * @see org.eclipse.gef.commands.Command#execute()
	 */
	public void execute() {
		if (Helpers.constraintHasAlreadyVOCLExpression(shell, parent)
			== 1) {
			return;
		}
		//open a dialog for editing the settings
		CreateLetExpressionDialog d = new CreateLetExpressionDialog(shell, 0);
		d.open();
		if (d.isCancelled())
			return;
		//set the alignment of the figure
		letexp.setIsVertical(d.isVertical());
		letexp.setIndex(position);
		//create a new Let-In-Expressioin
		VOCLModelFactory mfc = VOCLModelManager.getFactory();
		vardeclar = mfc.createVariableDeclaration();
		vardeclar.setVarName(d.getVarName());
		vardeclar.setType(d.getType());
		//insert VariableDeclaration into modell
		letexp.setVariableDeclaration(vardeclar);
		//insert Let-In-Expression into modell
		Helpers.addToParent(letexp, parent, position);
	}

	/**
	 * Sets the index - position for the parent.
	 * @param i
	 */
	public void setPosition(int i) {
		position = i;
	}

	/**
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	public void undo() {
		Helpers.removeFromParent(parent, position);
	}

	/**
	 * @see org.eclipse.gef.commands.Command#redo()
	 */
	public void redo() {
		Helpers.addToParent(letexp, parent, position);
	}

}
