package vocleditor.command;

import org.eclipse.gef.commands.Command;

import VOCLModel.AssociationEndRoleSource;
import VOCLModel.AssociationEndRoleTarget;
import VOCLModel.AssociationRole;
import VOCLModel.ClassifierNode;
import VOCLModel.NavExp;


/**
 * 
 * Class       : DeleteAssociationRoleCommand<br/>
 * Package     : vocleditor.command<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 12.06.2004<br/>
 * Description : Command for deleting an AssociationRole.<br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 */
public class DeleteAssociationRoleCommand extends Command {
	//the current AssociationRole
	private AssociationRole associationRole;
	//the AssociationEndRoleSource connected with the current AssociationRole
	private AssociationEndRoleSource endRoleSource;
	//the AssociationEndRoleTarget connected with the current AssociationRole
	private AssociationEndRoleTarget endRoleTarget;
	//the source ClassifierNode connected to the AssociationRole
	private ClassifierNode source;
	//the target ClassifierNode connected to the AssociationRole
	private ClassifierNode target;
	//the parent of the current AssociationRole
	private NavExp parent;
	
	/**
	 * Constructor.
	 * @param associationRole the current AssociationRole
	 */
	public DeleteAssociationRoleCommand(AssociationRole associationRole){
		this.associationRole = associationRole;
		//set the parent of the associationRole
		parent = associationRole.getNavExp();	
	}
	
	/**
	 * @see org.eclipse.gef.commands.Command#execute()
	 */
	public void execute(){
		endRoleSource = associationRole.getAssociationEndRoleSource();
		endRoleTarget = associationRole.getAssociationEndRoleTarget();
		source = endRoleSource.getClassifierNode();
		target = endRoleTarget.getClassifierNode();
		source.getAssociationEndRole().remove(endRoleSource);
		target.getAssociationEndRole().remove(endRoleTarget);
		parent.getAssociationRole().remove(associationRole);
	}
	
	/**
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	public void undo(){
		source.getAssociationEndRole().add(endRoleSource);
		target.getAssociationEndRole().add(endRoleTarget);
		parent.getAssociationRole().add(associationRole);
	}
}
