package vocleditor.command;

import org.eclipse.draw2d.Figure;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.commands.Command;

import VOCLModel.AssociationEndRole;

/**
 * 
 * Class       : MoveAssociationEndRoleCommand<br/>
 * Package     : vocleditor.command<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 08.06.2004<br/>
 * Description : Command for moving the Label of the AssociationRole.<br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 */
public class MoveAssociationEndRoleCommand extends Command
{

	AssociationEndRole label = null;
	Point location = null;
	Figure parent = null;
	Point oldOffset = new Point();

	/**
	 * Constructor.
	 * @param label - the label of the AssociationRole
	 * @param parent - the parent figure (e.g. NavExpContainerFigure)
	 * @param location - the coordinates of the label
	 */
	public MoveAssociationEndRoleCommand(AssociationEndRole label, Figure parent, Point location)
	{
		this.label = label;
		this.parent = parent;
		this.location = location;
	}

	/**
	 * @see org.eclipse.gef.commands.Command#execute()
	 */
	public void execute()
	{
		oldOffset = new Point(label.getX(), label.getY());
		Point newOffset = oldOffset.getCopy();
		parent.translateToAbsolute(newOffset);
		newOffset.translate(location);
		parent.translateToRelative(newOffset);
		label.setX(newOffset.x);
		label.setY(newOffset.y);
	}

	/**
	 * @see org.eclipse.gef.commands.Command#redo()
	 */
	public void redo()
	{
		execute();
	}

	/**
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	public void undo()
	{
		label.setX(oldOffset.x);
		label.setY(oldOffset.y);
	}
}