package vocleditor.command;

import vocleditor.model.VOCLModelManager;
import VOCLModel.BendPoint;
import VOCLModel.VOCLModelFactory;

/**
 * 
 * Class       : MoveBendpointCommand<br/>
 * Package     : vocleditor.command<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 01.07.2004<br/>
 * Description : Command for moving BendPoints.<br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 */
public class MoveBendpointCommand extends BendpointCommand {

	private BendPoint oldBendpoint;

	public void execute() {
		VOCLModelFactory mfc = VOCLModelManager.getFactory();
		//create a new Bendpoint for the Model
		BendPoint bp = mfc.createBendPoint();
		//set the relative Dimension to the source classifierRoleNode
		bp.getH().add(new Integer(getFirstRelativeDimension().height));
		bp.getW().add(new Integer(getFirstRelativeDimension().width));
		//set the relative Dimension to the target classifierRoleNode
		bp.getH().add(new Integer(getSecondRelativeDimension().height));
		bp.getW().add(new Integer(getSecondRelativeDimension().width));

		//store the oldBendpoint
		setOldBendpoint(
			(BendPoint) getAssociationRole().getBendPoint().get(getIndex()));
		
		//insert the new Bendpoint with the new Position into the Modell
		getAssociationRole().getBendPoint().set(getIndex(), bp);

	}

	/**
	 * Returns the old BendPoint
	 * @return the old BendPoint
	 */
	protected BendPoint getOldBendpoint() {
		return oldBendpoint;
	}

	/**
	 * Sets the old BendPoint.
	 * @param bp the old BendPoint
	 */
	public void setOldBendpoint(BendPoint bp) {
		oldBendpoint = bp;
	}

	/**
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	public void undo() {
		getAssociationRole().getBendPoint().set(getIndex(), oldBendpoint);
	}

}
