package vocleditor.edit;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartFactory;
import org.eclipse.swt.widgets.Shell;

import vocleditor.edit.parts.AssociationEndRoleSourceEditPart;
import vocleditor.edit.parts.AssociationEndRoleTargetEditPart;
import vocleditor.edit.parts.AssociationRoleEditPart;
import vocleditor.edit.parts.BoolExpEditPart;
import vocleditor.edit.parts.ClassifierRoleSetEditPart;
import vocleditor.edit.parts.ClassifierRoleSimpleEditPart;
import vocleditor.edit.parts.ConditionEditPart;
import vocleditor.edit.parts.ConstraintEditPart;
import vocleditor.edit.parts.DecisionEditPart;
import vocleditor.edit.parts.LetExpEditPart;
import vocleditor.edit.parts.NavExpEditPart;
import vocleditor.edit.parts.VOCLDiagrammEditPart;
import VOCLModel.AssociationEndRoleSource;
import VOCLModel.AssociationEndRoleTarget;
import VOCLModel.AssociationRole;
import VOCLModel.BoolExp;
import VOCLModel.ClassifierRole;
import VOCLModel.ClassifierRoleSet;
import VOCLModel.Condition;
import VOCLModel.Constraint;
import VOCLModel.IfExp;
import VOCLModel.LetExp;
import VOCLModel.NavExp;
import VOCLModel.VOCLDiagram;

/**
 * 
 * Class       : GraphicalEditPartsFactory<br/>
 * Package     : vocleditor.edit<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 26.06.2004<br/>
 * Description : Factory class to create graphical edit parts.<br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 */
public class GraphicalEditPartsFactory implements EditPartFactory {

	// We need to hand the shell over to the edit parts...
	private Shell shell;

	public GraphicalEditPartsFactory(Shell shell) {
		super();
		this.shell = shell;
	}

	/**
	 * Creates a new edit part.
	*/
	public EditPart createEditPart(EditPart context, Object obj) {
		if (obj instanceof VOCLDiagram) {
			VOCLDiagrammEditPart vPart =
				new VOCLDiagrammEditPart((VOCLDiagram) obj);
			vPart.setShell(shell);
			return vPart;
		} else if (obj instanceof NavExp) {
			NavExpEditPart nec = new NavExpEditPart((NavExp) obj);
			nec.setShell(shell);
			return nec;
		} else if (obj instanceof ClassifierRole) {
			ClassifierRoleSimpleEditPart cr =
				new ClassifierRoleSimpleEditPart((ClassifierRole) obj);
			cr.setShell(shell);
			return cr;

		} else if (obj instanceof ClassifierRoleSet) {
			ClassifierRoleSetEditPart cr =
				new ClassifierRoleSetEditPart((ClassifierRoleSet) obj);
			cr.setShell(shell);
			return cr;

		} else if (obj instanceof AssociationRole) {
			AssociationRoleEditPart ar =
			new AssociationRoleEditPart((AssociationRole)obj);
			return ar;
		} else if (obj instanceof AssociationEndRoleSource) {
			return new AssociationEndRoleSourceEditPart(
				(AssociationEndRoleSource) obj);
		} else if (obj instanceof AssociationEndRoleTarget) {
			return new AssociationEndRoleTargetEditPart(
				(AssociationEndRoleTarget) obj);
		} else if (obj instanceof Constraint) {
			ConstraintEditPart cons = new ConstraintEditPart((Constraint) obj);
			cons.setShell(shell);
			return cons;
		} else if (obj instanceof Condition){
			return new ConditionEditPart((Condition)obj);
		} else if (obj instanceof BoolExp){
			BoolExpEditPart bep=  new BoolExpEditPart((BoolExp)obj);
			bep.setShell(shell);
			return bep;
		} else if(obj instanceof IfExp){
			DecisionEditPart decPart = new DecisionEditPart((IfExp)obj);
			decPart.setShell(shell);
			return decPart;
		} else if(obj instanceof LetExp){
			LetExpEditPart letPart = new LetExpEditPart((LetExp)obj);
			letPart.setShell(shell);
			return letPart;
		}
		return null;
	}

	public Shell getShell() {
		return shell;
	}
}
