package vocleditor.edit.parts;

import java.util.LinkedList;
import java.util.List;

import org.eclipse.draw2d.IFigure;
import org.eclipse.emf.common.notify.Notifier;
import org.eclipse.gef.EditPolicy;
import org.eclipse.ui.views.properties.IPropertySource;

import vocleditor.edit.policies.VOCLExpLayoutEditPolicy;
import vocleditor.figures.BoolExpFigure;
import vocleditor.model.EObjectPropertySource;
import VOCLModel.BoolExp;

/**
 * Class       : BoolExpEditPart<br/>
 * Package     : vocleditor.edit.parts<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 22.05.2004<br/>
 * Description : This editpart represents a boolean expression<br/>
 * <br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 *
 *
 */
public class BoolExpEditPart
	extends VOCLExpEditPart{

	private IPropertySource propertySource = null;
	

	/**
	 * Constructor 
	 * @param boolExp
	 */
	public BoolExpEditPart(BoolExp boolExp) {
		//insert boolexp into Modell
		setModel(boolExp);
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#activate()
	 */
	public void activate() {
		if (isActive())
			return;
		((Notifier) getBoolExp()).eAdapters().add(this);
		if (getBoolExp().getFirstOp() != null) {
			getBoolExp().getFirstOp().eAdapters().add(this);
		}
		if (getBoolExp().getSecondOp() != null) {
			getBoolExp().getSecondOp().eAdapters().add(this);
		}

		super.activate();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#deactivate()
	 */
	public void deactivate() {
		if (!isActive())
			return;
		((Notifier) getBoolExp()).eAdapters().remove(this);
		super.deactivate();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#createFigure()
	 */
	protected IFigure createFigure() {
		BoolExpFigure figure = new BoolExpFigure();
		figure.setIndex(getBoolExp().getIndex());
		return figure;
	}

	/**
	 * Returns a BoolExpFigure
	 * @return
	 */
	public BoolExpFigure getBoolExpFigure() {
		return (BoolExpFigure) getFigure();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#createEditPolicies()
	 */
	protected void createEditPolicies() {
		installEditPolicy(
			EditPolicy.LAYOUT_ROLE,
			new VOCLExpLayoutEditPolicy());
		super.createEditPolicies();
	}
	
	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#getModelChildren()
	 */
	protected List getModelChildren() {
		List children = new LinkedList();
		//children that are on the FirstOpSide
		if (getBoolExp().getFirstOp() != null)
			children.add(getBoolExp().getFirstOp());
		//children that are on the SecondOpSide
		if (getBoolExp().getSecondOp() != null)
			children.add(getBoolExp().getSecondOp());
		
		return children;
	}
	/**
	 * @see com.ibm.itso.sal330r.gefdemo.edit.NetworkElementEditPart#getPropertySource()
	 */
	protected IPropertySource getPropertySource() {
		if (propertySource == null)
			propertySource = new EObjectPropertySource(getBoolExp());
		return propertySource;
	}
	/**
	 * Returns the model element represented by this edit part
	 * @return
	 */
	public BoolExp getBoolExp() {
		return (BoolExp) getModel();
	}


	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#refreshVisuals()
	 */
	protected void refreshVisuals() {
		BoolExp bool = getBoolExp();
		BoolExpFigure figure = getBoolExpFigure();
		//display the Kind of BoolOperation
		figure.setBoolOperation(bool.getKind().toString());
		//displays the figure vertical or horicontal
		figure.setVertical(bool.isIsVertical());
		super.refreshVisuals();
	}
}
