
package vocleditor.edit.parts;

import org.eclipse.draw2d.IFigure;
import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.Notifier;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.editparts.AbstractGraphicalEditPart;
import org.eclipse.ui.views.properties.IPropertySource;

import vocleditor.edit.policies.ConditionEditPolicy;
import vocleditor.figures.ConditionFigure;
import vocleditor.model.EObjectPropertySource;
import VOCLModel.Condition;
import VOCLModel.VariableDeclaration;

/**
 * Class       : ConditionEditPart<br/>
 * Package     : vocleditor.edit.parts<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 22.05.2004<br/>
 * Description : This editpart represents condition (not an if-then-else !)<br/>
 * <br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 *
 *
 */
public class ConditionEditPart
	extends AbstractGraphicalEditPart
	implements Adapter {

	public ConditionEditPart(Condition condition) {
		setModel(condition);
	}

	Notifier target;
	private IPropertySource propertySource = null;

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#activate()
	 */
	public void activate() {
		if (isActive())
			return;
		getCondition().eAdapters().add(this);
		super.activate();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#deactivate()
	 */
	public void deactivate() {
		if (!isActive())
			return;
		getCondition().eAdapters().remove(this);
		super.deactivate();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#createFigure()
	 */
	protected IFigure createFigure() {
		ConditionFigure f = new ConditionFigure();
//		f.setIndex(getCondition().getIndex());
		return f;
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#createEditPolicies()
	 */
	protected void createEditPolicies() {
		installEditPolicy(EditPolicy.COMPONENT_ROLE, new ConditionEditPolicy());
	}

	/**
	 * @see org.eclipse.emf.common.notify.Adapter#notifyChanged(org.eclipse.emf.common.notify.Notification)
	 */
	public void notifyChanged(Notification notification) {
		int type = notification.getEventType();
		switch (type) {
			case Notification.ADD :
			case Notification.ADD_MANY :
			case Notification.REMOVE :
			case Notification.REMOVE_MANY :
				refreshVisuals();
				break;
			case Notification.SET :
				refreshVisuals();
				break;
		}

	}

	/**
	 * @see org.eclipse.emf.common.notify.Adapter#getTarget()
	 */
	public Notifier getTarget() {
		return target;
	}

	protected IPropertySource getPropertySource() {
		if (propertySource == null)
			propertySource = new EObjectPropertySource(getCondition());
		return propertySource;
	}

	public Condition getCondition() {
		return (Condition) getModel();
	}

	/**
	 * @see org.eclipse.emf.common.notify.Adapter#setTarget(org.eclipse.emf.common.notify.Notifier)
	 */
	public void setTarget(Notifier target) {
		this.target = target;
	}

	/**
	 * @see org.eclipse.emf.common.notify.Adapter#isAdapterForType(java.lang.Object)
	 */
	public boolean isAdapterForType(Object type) {
		return type.equals(getModel().getClass());
	}

	public ConditionFigure getConditionFigure() {
		return (ConditionFigure) getFigure();
	}
	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#refreshVisuals()
	 */
	protected void refreshVisuals() {
		String name = "";
		Condition c = (Condition) getCondition();
		ConditionFigure figure = getConditionFigure();
		
		if (c != null) {

			VariableDeclaration v = c.getLeft();
			if (v != null) {
				name += v.getVarName();
				name += "  " + c.getOp();
				if (!c.getValue().equals("")) {
					name += "  " + c.getValue();
				} else {
					VariableDeclaration right = c.getRight();
					if (right != null)
						name += "  " + right.getVarName();
				}
			}
			figure.setCondition(name);
		}

		super.refreshVisuals();
	}

}
