package vocleditor.edit.parts;

import java.util.LinkedList;
import java.util.List;

import org.eclipse.draw2d.IFigure;
import org.eclipse.gef.EditPolicy;
import org.eclipse.ui.views.properties.IPropertySource;

import vocleditor.edit.policies.NavExpEditPolicy;
import vocleditor.edit.policies.NavExpXYLayoutEditPolicy;
import vocleditor.figures.NavExpContainerFigure;
import vocleditor.model.EObjectPropertySource;
import VOCLModel.Condition;
import VOCLModel.NavExp;

/**
 * Class       : NavExpEditPart<br/>
 * Package     : vocleditor.edit.parts<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 22.05.2004<br/>
 * Description : This editpart represents a navigation expression<br/>
 * <br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 *
 * 
 */
public class NavExpEditPart extends VOCLExpEditPart  {

	private IPropertySource propertySource = null;


	/**
	 * Creates a new edit part for a petri net model.
	 */
	public NavExpEditPart(NavExp navExp) {
		setModel(navExp);
	}

	/**
	 * Returns the NavExp for which this object is the edit part.
	 */
	public NavExp getNavExp() {
		return (NavExp) getModel();
	}

	/**
	 * Creates the figure.
	 */
	protected IFigure createFigure() {
		NavExpContainerFigure figure =
			new NavExpContainerFigure();
		figure.setIndex(getNavExp().getIndex());
		return figure;
	}

	/**
	 * Creates the edit policies.
	 */
	protected void createEditPolicies() {
		installEditPolicy(EditPolicy.CONTAINER_ROLE, new NavExpEditPolicy());
		installEditPolicy(
			EditPolicy.LAYOUT_ROLE,
			new NavExpXYLayoutEditPolicy());
		super.createEditPolicies();
	}

	/**
	 * Returns the elements of the petri net (places and transitions).
	 */

	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#getModelChildren()
	 */
	protected List getModelChildren() {
		List children = new LinkedList();
		children.addAll(getNavExp().getClassifierNode());
		if (getNavExp().getCondition() != null) {
			children.add(getNavExp().getCondition());
		}
		return children;
	}

	
	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#activate()
	 */
	public void activate() {
		if (isActive())
			return;

		// start listening for changes in the model
		getNavExp().eAdapters().add(this);
//		Condition cond = getNavExp().getCondition();
//		if (cond != null) {
//			cond.eAdapters().add(this);
//		}
		super.activate();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#deactivate()
	 */
	public void deactivate() {
		if (!isActive())
			return;

		// stop listening for changes in the model
//		if (getNavExp().getCondition() != null) {
//			getNavExp().getCondition().eAdapters().remove(this);
//		}
		getNavExp().eAdapters().remove(this);

		super.deactivate();
	}

	/**
	 * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
	 */
	public Object getAdapter(Class key) {
		if (IPropertySource.class == key)
			return getPropertySource();
		return super.getAdapter(key);
	}
	/**
	 * @see com.ibm.itso.sal330r.gefdemo.edit.NetworkElementEditPart#getPropertySource()
	 */
	protected IPropertySource getPropertySource() {
		if (propertySource == null)
			propertySource = new EObjectPropertySource(getNavExp());
		return propertySource;
	}

	//	/**
	//	 * Method getShell
	//	 * @return
	//	 */
	//	public Shell getShell() {
	//		return shell;
	//	}
	//
	//	/**
	//	 * Method setShell
	//	 * @param shell
	//	 */
	//	public void setShell(Shell shell) {
	//		this.shell = shell;
	//	}

	protected void refreshVisuals() {
		super.refreshVisuals();
	}

	public NavExpContainerFigure getNavExpContainerFigure() {
		return (NavExpContainerFigure) getFigure();
	}

	List children = null;
	/**
	 * @see org.eclipse.gef.GraphicalEditPart#getContentPane()
	 */
//	public IFigure getContentPane() {
//		return getNavExpContainerFigure().getContentsPane();
//	}

}
