package vocleditor.edit.parts;

import java.util.List;

import org.eclipse.draw2d.FreeformLayer;
import org.eclipse.draw2d.FreeformLayout;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.LineBorder;
import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.Notifier;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.editparts.AbstractGraphicalEditPart;
import org.eclipse.gef.editpolicies.RootComponentEditPolicy;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.views.properties.IPropertySource;

import vocleditor.edit.policies.VOCLDiagrammEditPolicy;
import vocleditor.edit.policies.VOCLDiagrammXYLayoutEditPolicy;
import vocleditor.model.EObjectPropertySource;
import VOCLModel.VOCLDiagram;

/**
 * Class       : VOCLDiagrammEditPart<br/>
 * Package     : vocleditor.edit.parts<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 22.05.2004<br/>
 * Description : This editpart represents the whole VOCL diagram<br/>
 * <br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 *
 * 
 */
public class VOCLDiagrammEditPart
	extends AbstractGraphicalEditPart
	implements Adapter {

	private Notifier target;
	private IPropertySource propertySource = null;

	private Shell shell;

	/**
	 * Creates a new edit part for a petri net model.
	 */
	public VOCLDiagrammEditPart(VOCLDiagram navExp) {
		setModel(navExp);
	}


	/**
	 * Returns the VOCLDiagramm for which this object is the edit part.
	 */
	public VOCLDiagram getVOCLDiagramm() {
		return (VOCLDiagram) getModel();
	}

	/**
	 * Creates the figure.
	 */
	protected IFigure createFigure() {
		FreeformLayer layer = new FreeformLayer();
		layer.setLayoutManager(new FreeformLayout());
		layer.setBorder(new LineBorder(1));
		return layer;
	}

	/**
	 * Creates the edit policies.
	 */
	protected void createEditPolicies() {
		installEditPolicy(EditPolicy.CONTAINER_ROLE, new VOCLDiagrammEditPolicy());
		installEditPolicy(
			EditPolicy.LAYOUT_ROLE,
			new VOCLDiagrammXYLayoutEditPolicy());
		installEditPolicy(EditPolicy.NODE_ROLE, null);
		installEditPolicy(EditPolicy.GRAPHICAL_NODE_ROLE, null);
		
		installEditPolicy(
			EditPolicy.COMPONENT_ROLE,
			new RootComponentEditPolicy());
	
	}

	/**
	 * Returns the elements of the petri net (places and transitions).
	 */
	protected List getModelChildren() {
		return getVOCLDiagramm().getConstraint();
	}

	/**
	 * @see org.eclipse.emf.common.notify.Adapter#getTarget()
	 */
	public Notifier getTarget() {
		return target;
	}

	/**
	 * @see org.eclipse.emf.common.notify.Adapter#setTarget(org.eclipse.emf.common.notify.Notifier)
	 */
	public void setTarget(Notifier newTarget) {
		target = newTarget;
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#activate()
	 */
	public void activate() {
		if (isActive())
			return;

		// start listening for changes in the model
		 ((Notifier) getVOCLDiagramm()).eAdapters().add(this);

		super.activate();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#deactivate()
	 */
	public void deactivate() {
		if (!isActive())
			return;

		// stop listening for changes in the model
		 ((Notifier) getVOCLDiagramm()).eAdapters().remove(this);

		super.deactivate();
	}
	/**
		 * @see org.eclipse.emf.common.notify.Adapter#notifyChanged(org.eclipse.emf.common.notify.Notification)
		 */
	public void notifyChanged(Notification notification) {
		int type = notification.getEventType();
		switch (type) {
			case Notification.ADD :
			case Notification.ADD_MANY :
			case Notification.REMOVE :
			case Notification.REMOVE_MANY :
				refreshChildren();
				break;
			case Notification.SET :
				refreshVisuals();
				break;
		}
	}

	/**
	 * @see org.eclipse.emf.common.notify.Adapter#isAdapterForType(java.lang.Object)
	 */
	public boolean isAdapterForType(Object type) {
		return type.equals(getModel().getClass());
	}

	/**
	 * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
	 */
	public Object getAdapter(Class key) {
		if (IPropertySource.class == key)
			return getPropertySource();
		return super.getAdapter(key);
	}
	/**
	 * @see com.ibm.itso.sal330r.gefdemo.edit.NetworkElementEditPart#getPropertySource()
	 */
	protected IPropertySource getPropertySource() {
		if (propertySource == null)
			propertySource = new EObjectPropertySource(getVOCLDiagramm());
		return propertySource;
	}

	/**
	 * Method getShell
	 * @return
	 */
	public Shell getShell() {
		return shell;
	}

	/**
	 * Method setShell
	 * @param shell
	 */
	public void setShell(Shell shell) {
		this.shell = shell;
	}

}
