/*
 * Created on 14.05.2004
 */
package vocleditor.edit.policies;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.editpolicies.GraphicalNodeEditPolicy;
import org.eclipse.gef.requests.CreateConnectionRequest;
import org.eclipse.gef.requests.GroupRequest;
import org.eclipse.gef.requests.ReconnectRequest;

import vocleditor.command.AssociationRoleConnectionCommand;
import vocleditor.command.DeleteClassifierRoleCommand;
import vocleditor.edit.parts.AbstractClassifierRole;
import vocleditor.edit.parts.ClassifierRoleSetEditPart;
import VOCLModel.AssociationRole;
import VOCLModel.ClassifierRoleSet;

/**
 * Class       : ClassifierRoleSetEditPolicy<br/>
 * Package     : vocleditor.edit.policies<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 22.05.2004<br/>
 * Description : This policy is for editing a classifier set<br/>
 * <br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 *
 * 
 */
public class ClassifierRoleSetEditPolicy extends GraphicalNodeEditPolicy {


	/**
	 * @see org.eclipse.gef.editpolicies.ConnectionEditPolicy#getDeleteCommand(org.eclipse.gef.requests.GroupRequest)
	 */
	protected Command getDeleteCommand(GroupRequest request) {
		DeleteClassifierRoleCommand command = new DeleteClassifierRoleCommand(((ClassifierRoleSetEditPart)getHost()).getShell());
		command.setClassifierRole(getClassifierRoleSet());
		return command;
	}

	/**
	 * Retrieves the classifier role set from model.
	 *
	 * @return
	 */
	protected ClassifierRoleSet getClassifierRoleSet() {
		return (ClassifierRoleSet) getHost().getModel();
	}

	/**
	 * Returns the corresponding edit part
	 * 
	 * @return
	 */
	protected ClassifierRoleSetEditPart getClassifierRoleSetEditPart() {
		return (ClassifierRoleSetEditPart) getHost();
	}
	/**
	 * @see org.eclipse.gef.editpolicies.GraphicalNodeEditPolicy#getConnectionCompleteCommand(org.eclipse.gef.requests.CreateConnectionRequest)
	 */
	protected Command getConnectionCompleteCommand(CreateConnectionRequest request) {
		Command connectionCompleteCommand = null;

		if (request.getStartCommand()
			instanceof AssociationRoleConnectionCommand) {
			AssociationRoleConnectionCommand command =
				(AssociationRoleConnectionCommand) request.getStartCommand();
			command.setTarget(getClassifierRoleSet());
			connectionCompleteCommand = command;
		}

		return connectionCompleteCommand;
	}

	/**
	 * @see org.eclipse.gef.editpolicies.GraphicalNodeEditPolicy#getReconnectTargetCommand(org.eclipse.gef.requests.ReconnectRequest)
	 */
	protected Command getReconnectTargetCommand(ReconnectRequest request) {
		return null;
	}

	/**
	 * @see org.eclipse.gef.editpolicies.GraphicalNodeEditPolicy#getReconnectSourceCommand(org.eclipse.gef.requests.ReconnectRequest)
	 */
	protected Command getReconnectSourceCommand(ReconnectRequest request) {
		
		return null;
	}

	/**
	 * Returns a connection command to connect this classifier role with another.
	 */
	protected Command getConnectionCreateCommand(CreateConnectionRequest request) {
		Command connectionCreateCommand = null;

		if (request.getNewObjectType() == AssociationRole.class) {
			AssociationRoleConnectionCommand command =
				new AssociationRoleConnectionCommand();
			command.setSource(getClassifierRoleSet());
			command.setShell(((AbstractClassifierRole)getHost()).getShell());
			command.setAssociationRole(
				(AssociationRole) request.getNewObject());
			request.setStartCommand(command);
			connectionCreateCommand = command;
		}

		return connectionCreateCommand;
	}

}
