package vocleditor.editor;

import org.eclipse.gef.ContextMenuProvider;
import org.eclipse.gef.EditDomain;
import org.eclipse.gef.GraphicalViewer;
import org.eclipse.gef.editparts.ScalableFreeformRootEditPart;
import org.eclipse.gef.ui.parts.GraphicalViewerKeyHandler;
import org.eclipse.gef.ui.parts.ScrollingGraphicalViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;

import vocleditor.actions.VOCLContextMenuProvider;
import vocleditor.edit.GraphicalEditPartsFactory;

public class VOCLDiagrammPage extends AbstractEditorPage {
	
	/**
	 * Creates a new VOCLDiagramPage instance.
	 * 
	 * <p>By design this page uses its own <code>EditDomain</code>.
	 * The main goal of this approach is that this page has its own
	 * undo/redo command stack.
	 * 
	 * @param parent the parent multi page editor 
	 */
	public VOCLDiagrammPage(VOCLDiagrammEditor parent) {
		super(parent, new EditDomain());
	}

	/**
	 * @see com.ibm.itso.sal330r.gefdemo.editor.AbstractEditorPage#getPageName()
	 */
	protected String getPageName() {
		return "VOCLDiagramEditor";
	}

	/**
	 * @see com.ibm.itso.sal330r.gefdemo.editor.AbstractEditorPage#createPageControl(org.eclipse.swt.widgets.Composite)
	 */
	protected void createPageControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setBackground(parent.getBackground());
		composite.setLayout(new GridLayout(2, false));

		createPaletteViewer(composite);
		GridData gd = new GridData(GridData.FILL_VERTICAL);
		gd.widthHint = 125;
		getPaletteViewer().getControl().setLayoutData(gd);

		createGraphicalViewer(composite);
		gd = new GridData(GridData.FILL_BOTH);
		gd.widthHint = 275;
		getGraphicalViewer().getControl().setLayoutData(gd);
	}

	/** the graphical viewer */
	private GraphicalViewer viewer;

	/**
	 * Creates the GraphicalViewer on the specified <code>Composite</code>.
	 * @param parent the parent composite
	 */
	private void createGraphicalViewer(Composite parent) {
		viewer = new ScrollingGraphicalViewer();
		viewer.createControl(parent);

		// configure the viewer
		viewer.getControl().setBackground(parent.getBackground());
		viewer.setRootEditPart(new ScalableFreeformRootEditPart());
		viewer.setKeyHandler(new GraphicalViewerKeyHandler(viewer));

		// hook the viewer into the editor
		registerEditPartViewer(viewer);

		// configure the viewer with drag and drop
		configureEditPartViewer(viewer);

		// initialize the viewer with input
		viewer.setEditPartFactory(new GraphicalEditPartsFactory(getSite().getShell()));
		viewer.setContents(getVOCLDiagrammEditor().getVOCLDiagramm());
		ContextMenuProvider provider =
			new VOCLContextMenuProvider(
 			getGraphicalViewer(),
				getVOCLDiagrammEditor().getActionRegistry());
		getGraphicalViewer().setContextMenu(provider);
		getSite().registerContextMenu(provider, getGraphicalViewer());

	}

	/**
	 * @see com.ibm.itso.sal330r.gefdemo.editor.AbstractEditorPage#getGraphicalViewerForZoomSupport()
	 */
	protected GraphicalViewer getGraphicalViewer() {
		return viewer;
	}
}
