package vocleditor.editor;

import org.eclipse.gef.palette.ConnectionCreationToolEntry;
import org.eclipse.gef.palette.CreationToolEntry;
import org.eclipse.gef.palette.MarqueeToolEntry;
import org.eclipse.gef.palette.PaletteGroup;
import org.eclipse.gef.palette.PaletteRoot;
import org.eclipse.gef.palette.SelectionToolEntry;
import org.eclipse.gef.palette.ToolEntry;

import vocleditor.model.ModelCreationFactory;
import VOCLModel.AssociationRole;
import VOCLModel.BoolExp;
import VOCLModel.ClassifierRole;
import VOCLModel.ClassifierRoleSet;
import VOCLModel.Condition;
import VOCLModel.Constraint;
import VOCLModel.IfExp;
import VOCLModel.LetExp;
public class VOCLDiagrammPaletteRoot extends PaletteRoot {
	/**
	 * Creates a new VOCLDiagramPaletteRoot instance.
	 * 
	 */
	public VOCLDiagrammPaletteRoot() {
		// create root
		super();

		
		// a group of default control tools
		PaletteGroup controls = new PaletteGroup("Controls");
		add(controls);
		// the selection tool
		ToolEntry tool = new SelectionToolEntry();
		controls.add(tool);

		// use selection tool as default entry
		setDefaultEntry(tool);

		// the marquee selection tool
		controls.add(new MarqueeToolEntry());

		CreationToolEntry entry;
		PaletteGroup navexps = new PaletteGroup("Simple Elements");
		PaletteGroup other = new PaletteGroup("other");
		PaletteGroup exps = new PaletteGroup("expressions");
		add(other);
		add(navexps);
		add(exps);

		entry =
			new CreationToolEntry(
				"ClassifierRole",
				"Creates a ClassifierRole",
				new ModelCreationFactory(ClassifierRole.class),
				null,
				null);
		navexps.add(entry);

		entry =
			new CreationToolEntry(
				"ClassifierRoleSet",
				"Creates a ClassifierRoleSet",
				new ModelCreationFactory(ClassifierRoleSet.class),
				null,
				null);
		navexps.add(entry);

		entry =
			new ConnectionCreationToolEntry(
				"AssociationRole",
				"Creates a AssociationRole",
				new ModelCreationFactory(AssociationRole.class),
				null,
				null);
		navexps.add(entry);

		entry =
			new CreationToolEntry(
				"Constraint",
				"Creates a Constraint",
				new ModelCreationFactory(Constraint.class),
				null,
				null);
		other.add(entry);

		entry =
			new CreationToolEntry(
				"Condition",
				"Creates a Condition",
				new ModelCreationFactory(Condition.class),
				null,
				null);
		other.add(entry);

		entry =
			new CreationToolEntry(
				"BoolExp",
				"Creates a BoolExp",
				new ModelCreationFactory(BoolExp.class),
				null,
				null);
		exps.add(entry);

		entry =
			new CreationToolEntry(
				"If-then-else",
				"Creates a If-then-else-Exp",
				new ModelCreationFactory(IfExp.class),
				null,
				null);
		exps.add(entry);
		entry =
			new CreationToolEntry(
				"LetExp",
				"Creates a LetExpression",
				new ModelCreationFactory(LetExp.class),
				null,
				null);
		exps.add(entry);
		

	}
}
