package vocleditor.figures;

import org.eclipse.draw2d.PolylineConnection;
import org.eclipse.draw2d.RectangleFigure;
import org.eclipse.draw2d.geometry.Point;

/**
 * @author Stefan
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
/**
 * 
 * Class       : SimpleClassifierRoleFigure<br/>
 * Package     : vocleditor.edit.parts<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 22.05.2004<br/>
 * Description : Abstract base class for the LetExpFigure, DecisionFigure, NavExpContainerFigure, BoolExpFigure.<br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 */
public abstract class VOCLExpFigure extends RectangleFigure {

	protected int index = 0;
	private PolylineConnection ltToRb;
	private PolylineConnection lbToRt;
	private boolean negated = false;
	
	public VOCLExpFigure(){
		ltToRb = new PolylineConnection();
		lbToRt = new PolylineConnection();
		add(ltToRb);
		add(lbToRt);
	}
	
	/**
	 * Returns the index of this figure, so that the parentfigure knows
	 * on which side this figure should be placed.
	 * @return the index
	 */
	public int getIndex(){
		return index;
	}
	
	/**
	 * Sets the index of this figure so that the parentfigure knows
	 * on which side this figure should be placed.
	 * @param i the index
	 */
	public void setIndex(int i){
		index = i;
	}
	
	/**
	 * Determines whether the figure should be negated or not.
	 * @param b
	 */
	public void setNegated(boolean b){
		negated = b;				
	}
	/**
	 * @see org.eclipse.draw2d.Figure#useLocalCoordinates()
	 */
	protected boolean useLocalCoordinates() {
		return true;
	}
	
	/**
	 * @see org.eclipse.draw2d.IFigure#validate()
	 */
	public void validate(){
		ltToRb.setVisible(negated);
		lbToRt.setVisible(negated);
		if (negated){
			ltToRb.setStart(new Point(0,0));
			ltToRb.setEnd(new Point(getSize().width, getSize().height));
			lbToRt.setStart(new Point(0, getSize().height));
			lbToRt.setEnd(new Point( getSize().width, 0));
		}
		super.validate();		
	}
	
	
	/**
	 * Returns the position of the childfigures in the parent figure.
	 * @return the position as Integer
	 */
	public abstract int returnBereich();
	
	/**
	 * Returns the Location of the NavExpContainerFiguer where the ClassifierNode should
	 * be placed.
	 * @return the Location.
	 */
	public abstract Point getClassifierLocation();

	protected boolean isVertical = true;
	
	protected boolean isVertical(){
		return isVertical;
	}
}
