/*
 * Created on 19.06.2004
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package vocleditor.model;

import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Vector;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.widgets.Shell;

import VOCLModel.BoolExp;
import VOCLModel.Constraint;
import VOCLModel.Context;
import VOCLModel.IfExp;
import VOCLModel.LetExp;
import VOCLModel.NavExp;
import VOCLModel.VOCLExpression;
import VOCLModel.VariableDeclaration;


/**
 * Class       : Helpers<br/>
 * Package     : vocleditor.model<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 22.05.2004<br/>
 * Description : In this class we provide small static methods which help us by doing several things faster.<br/>
 * <br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 *
 * 
 */
public class Helpers {
	private static List list = new LinkedList();
	
	/**
	 * This method handles the situation if a VOCL Expression is added to 
	 * a constraint which already contains a VOCL expression through 
	 * warning the user.
	 * 
	 * @param shell
	 * @param parent
	 * @return
	 */
	public static int constraintHasAlreadyVOCLExpression(Shell shell, Object parent) {
		if (parent instanceof Constraint) {
			if (((Constraint) parent).getVOCLExpression() != null) {
				String text =
					"Dieses Constraint beinhaltet bereits eine VOCLExpression\n"
						+ "Wollen Sie diese wirklich berschreiben (lschen)?";
				String title = "Constraint ist nicht leer";
				String[] buttons = { "OK", "Cancel" };

				MessageDialog d =
					new MessageDialog(
						shell,
						title,
						null,
						text,
						MessageDialog.WARNING,
						buttons,
						0);
				d.open();
				return d.getReturnCode();
			}
			return -1;
		}
		return -1;
	}

	/**
	 * Extract and return the variable declaration of a let expression within 
	 * a navigation expression. 
	 * 
	 * @param navexp
	 * @return
	 */
	public static VariableDeclaration getLetExpVariablenDeclaration(NavExp navexp) {
		EObject object = navexp.eContainer();
		while (true) {
			if (object instanceof LetExp) {
				return ((LetExp) object).getVariableDeclaration();
			} else if (object instanceof Constraint || object == null) {
				return null;
			}
			object = object.eContainer();
		}
	}

	/**
	 * Checks if a specified variable declaration is already defined within 
	 * the given navigation expression.
	 * 
	 * @param navexp
	 * @param varname
	 * @param forAttribute
	 * @return
	 */
	public static boolean checkVariableAlreadyExists(
		NavExp navexp,
		String varname,
		boolean forAttribute) {
		Constraint constraint = searchConstraint(navexp);
		Context context = constraint.getConstraintContext();
		
		List variablen = new Vector();
		variablen.addAll(navexp.getVariableDeclaration());
		if (!forAttribute) {
			if (getLetExpVariablenDeclaration(navexp) != null)
				variablen.add(getLetExpVariablenDeclaration(navexp));
		}

		//if there exists a LetExp, add the VariableDeclaration of it

		boolean result = false;
		for (Iterator it = variablen.iterator(); it.hasNext();) {
			VariableDeclaration variablenDeclaration =
				(VariableDeclaration) it.next();
			if (variablenDeclaration != null) {
				if (variablenDeclaration.getVarName().equals(varname) && !varname.equals("self") && !varname.equals(context.getName())) {
					result = true;
				}
			}

		}
		return result;
	}

	/**
	 * Removes a navigation expression from its parent.
	 * We have made this because the parent could be a
	 * VOCL expression or a contraint which are not inherited
	 * by the same classes.
	 * 
	 * @param parent
	 * @param position
	 */
	public static void removeFromParent(Object parent, int position) {
		if (parent instanceof Constraint) {
			((Constraint) parent).setVOCLExpression(null);
		} else if (parent instanceof BoolExp) {
			if (position == 1) {
				((BoolExp) parent).setFirstOp(null);
			} else {
				((BoolExp) parent).setSecondOp(null);
			}
		} else if (parent instanceof LetExp) {
			if (position == 1) {
				((LetExp) parent).setDef(null);
			} else {
				((LetExp) parent).setInExp(null);
			}
		} else if (parent instanceof IfExp) {
			if (position == 1) {
				((IfExp) parent).setIfCondition(null);
			} else if (position == 2) {
				((IfExp) parent).setThenExp(null);
			} else if (position == 3) {
				((IfExp) parent).setElseExp(null);
			}
		}

	}

	/**
	 * Adds a VOCL expression to the parent (constraint or VOCL Expression)
	 * 
	 * @param voclExpr
	 * @param parent
	 * @param position
	 */
	public static void addToParent(
		VOCLExpression voclExpr,
		Object parent,
		int position) {

		if (parent instanceof Constraint) {
			((Constraint) parent).setVOCLExpression(voclExpr);
		} else if (parent instanceof BoolExp) {
			if (position == 1) {

				((BoolExp) parent).setFirstOp(voclExpr);
			} else {

				((BoolExp) parent).setSecondOp(voclExpr);
			}
		} else if (parent instanceof LetExp) {
			if (position == 1) {
				((LetExp) parent).setDef(voclExpr);
			} else {
				((LetExp) parent).setInExp(voclExpr);
			}
		} else if (parent instanceof IfExp) {
			if (position == 1) {
				((IfExp) parent).setIfCondition(voclExpr);
			} else if (position == 2) {
				((IfExp) parent).setThenExp(voclExpr);
			} else if (position == 3) {
				((IfExp) parent).setElseExp(voclExpr);
			}
		}
	}
	

	/**
	 * Search for a constraint within an EObject.
	 * 
	 * @param object
	 * @return
	 */
	public static Constraint searchConstraint(EObject object) {
		Constraint help = null;
		while (true) {
			if (object.eContainer() instanceof Constraint) {
				help = (Constraint) object.eContainer();
				break;
			} else {
				object = object.eContainer();
			}
		}
		return help;
	}

	
	/**
	 * Return all the navigation expressions within a VOCL expression.
	 * @param voclExpression
	 * @return
	 */
	public static List getNavExps(EObject voclExpression) {
		if (voclExpression instanceof BoolExp) {
			getNavExps(((BoolExp) voclExpression).getFirstOp());
			getNavExps(((BoolExp) voclExpression).getSecondOp());
		} else if (voclExpression instanceof IfExp) {
			getNavExps(((IfExp) voclExpression).getIfCondition());
			getNavExps(((IfExp) voclExpression).getThenExp());
			getNavExps(((IfExp) voclExpression).getElseExp());
		} else if (voclExpression instanceof NavExp) {
			list.add(voclExpression);
		}

		return list;
	}
}
