package vocleditor.model;

import java.util.List;
import java.util.Vector;

import org.eclipse.draw2d.AbstractConnectionAnchor;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.draw2d.geometry.PrecisionPoint;
import org.eclipse.draw2d.geometry.Rectangle;

/**
 * Class       : NavExpEditorAnchor<br/>
 * Package     : vocleditor.model<br/>
 * Project     : VOCLEditor<br/>
 * Created On  : 22.05.2004<br/>
 * Description : This class represents an anchor (connection points of association roles).<br/>
 * <br/>
 * @author Gruppe 1: Stefan Hnsgen, 
 * 					 Andre Hernich,
 * 			 		 Maximilian Kern,
 *		 			 Sebastian Russin<br>
 *
 * 
 */
public class NavExpEditorAnchor extends AbstractConnectionAnchor {

	private int xOffset;
	private int yOffset;

	/**
	 *   Creates a new anchor. 
	 */
	public NavExpEditorAnchor() {

		super();
		this.xOffset = 0;
		this.yOffset = 0;
	}

	/**
	 * Creates a new anchor.
	 * 
	 * @param owner
	 */
	public NavExpEditorAnchor(IFigure owner) {
		super(owner);
	}

	/**
	 * Sets the offset of this anchor.
	 * 
	 * @param offset
	 */
	public void setOffset(int x, int y) {
		xOffset = x;
		yOffset = y;
	}

	/**
	 * @see org.eclipse.draw2d.ConnectionAnchor#getLocation(org.eclipse.draw2d.geometry.Point)
	 */
	public Point getLocation() {
		Rectangle r = getOwner().getBounds();
		int x, y;
		x = r.x + xOffset;
		y = r.y + yOffset;

		Point p = new PrecisionPoint(x, y);
		getOwner().translateToAbsolute(p);
		return p;
	}

	/**
	 * Return the x coordinate from this anchor.
	 * @return
	 */
	public int getxOffset() {
		return xOffset;
	}

	/**
		 * Return the y coordinate from this anchor.
		 * @return
		 */
	public int getyOffset() {
		return yOffset;
	}

	/**
	 * Returns the closest anchor from the given anchor list.
	 * The mouse point is determined via the IAnchorFigure interface.
	 * 
	 * @param figure
	 * @param connectionAnchors
	 * @return
	 */
	public static NavExpEditorAnchor getClosestConnectionAnchor(IAnchorFigure figure, List connectionAnchors) {
		NavExpEditorAnchor closest = null;
		long min = Long.MAX_VALUE;
		
		Point p = figure.getMousePoint();
		figure.getFigure().getParent().translateToAbsolute(p);
		int h = 0;
		for (int i = 0; i < 8; i++) {
			NavExpEditorAnchor c =
				(NavExpEditorAnchor) connectionAnchors.get(i);
			Point p2 = c.getLocation();
			long d = p.getDistance2(p2);
			if (d < min) {
				min = d;
				closest = c;
				h = i;
			}
		}
		return closest;
	}
	
	/**
	 * Attaches or (if already attached) refreshes the anchors to/of the specified
	 * figure.
	 * 
	 * @param anchorFigure
	 */
	public static void attachAndRefreshAnchors(IAnchorFigure anchorFigure) {
		NavExpEditorAnchor anchor;
		IFigure figure = anchorFigure.getFigure();
		double widthSpace =figure.getSize().width / 2;
		double heightSpace = figure.getSize().height /2;
		
		Vector srcList, targetList;
		srcList = anchorFigure.getSourceAnchorList();
		targetList = anchorFigure.getSourceAnchorList();
		boolean refresh = srcList != null;
		if (srcList == null){
			srcList = new Vector();
			targetList = new Vector();
			anchorFigure.setSourceAnchorList(srcList);
			anchorFigure.setTargetAnchorList(targetList);
		}
		for (int x = 0; x < 8; x++) {
			if (refresh){
				anchor = (NavExpEditorAnchor)srcList.get(x);				
			} else {
				anchor = new NavExpEditorAnchor(figure);
				srcList.add(anchor);
				targetList.add(anchor);
			}			
			
			int offsetX = 0;
			int offsetY = 0;

			if (x <= 2) {
				offsetY = 0;
				offsetX = (int) (x * widthSpace);
			} else {
				if (x <= 4) {
					offsetX = (int) (widthSpace * 2);
					offsetY = (int) ((x - 2) * heightSpace);
				} else {
					if (x <= 6) {
						offsetX = (int) ((6-x) * widthSpace);
						offsetY = (int) (heightSpace * 2);
					} else {
						if (x <= 8) {
							offsetX = 0;
							offsetY = (int) (heightSpace);
						}
					}
				}

			}
			anchor.setOffset(offsetX, offsetY);
		}

	}
	/**
	 * @see org.eclipse.draw2d.ConnectionAnchor#getReferencePoint()
	 */
	public Point getReferencePoint() {
		return getLocation(null);
	}

	/**
	 * @see org.eclipse.draw2d.ConnectionAnchorBase#getLocation(org.eclipse.draw2d.geometry.Point)
	 */
	public Point getLocation(Point arg0) {
		return getLocation();
	}

}
